pub struct Rc<T: ?Sized, Owner: ?Sized = dyn Destruct> { /* private fields */ }
A projecting version of Rc which allows owning a containing struct but referencing a field.

Implementations

Constructs a new Rc<T> .

Erases the owning type so projected Rc can be used uniformly.

Provides a raw pointer to the data.

Creates a new Weak pointer to this projected field.

Gets a reference to the owning allocation.

This returns a clone of the owning Rc, so it cannot return a unique reference. If you want to take unique ownership, use into_owner instead.

Consumes this projected field and returns the owning allocation.

Projects this allocation to a field.

Note that the projected field is not required to actually be owned by the owner; it could be any longer-lived reference.

Returns true if the two Rcs point to the same allocation (in a vein similar to ptr::eq).

Available on crate feature unsize only.

Convert this pointer with an unsizing coercion (e.g. from T to dyn Trait or [T; N] to [T]).

Available on crate feature unsize only.

Convert this pointer with an unsizing coercion of the owner (e.g. from T to dyn Trait or [T; N] to [T]).