Module sync

Thread-safe reference-counting pointers.

See the Arc documentation for more details.

Structs

Arc
A projecting version of Arc which allows owning a containing struct but referencing a field.
Weak
A projecting version of Weak which allows owning a containing struct but referencing a field.