Struct Arc

pub struct Arc<T: ?Sized, Owner: ?Sized = dyn Destruct + Send + Sync> { /* private fields */ }
A projecting version of Arc which allows owning a containing struct but referencing a field.

Implementations

Source

impl<'a, T: 'a + Send + Sync> Arc<T, dyn Destruct + Send + Sync + 'a>

pub fn new(this: T) -> Self

Constructs a new Arc<T> with erased owner.

Source

impl<T> Arc<T, T>

pub fn new_owner(this: T) -> Self

Constructs a new Arc<T, T> with typed owner.

Source

impl<'a, T: ?Sized, Owner: 'a + Send + Sync> Arc<T, Owner>

pub fn erase_owner(this: Self) -> Arc<T, dyn Destruct + Send + Sync + 'a>

Erases the owning type so projected Arc<T> can be used uniformly.

Source

impl<T: ?Sized, Owner: ?Sized> Arc<T, Owner>

pub fn as_ptr(this: &Self) -> *const T

Provides a raw pointer to the data.

pub fn downgrade(this: &Self) -> Weak<T, Owner>

Creates a new Weak pointer to this projected field.

pub fn owner(this: &Self) -> Arc<Owner>

Gets a reference to the owning allocation.

This returns a clone of the owning Arc, so it cannot return a unique reference. If you want to take unique ownership, use into_owner instead.

pub fn into_owner(this: Self) -> Arc<Owner>

Consumes this projected field and returns the owning allocation.

pub fn project<U: ?Sized>( this: Self, projection: impl FnOnce(&T) -> &U, ) -> Arc<U, Owner>

Projects this allocation to a field.

Note that the projected field is not required to actually be owned by the owner; it could be any longer-lived reference.

pub fn ptr_eq(lhs: &Self, rhs: &Self) -> bool

Returns true if the two Arcs point to the same field in the same allocated object.

See ptr::eq for the caveats when comparing dyn Trait pointers, which this does when the owner type is erased.

Source

impl<T: ?Sized, Owner: ?Sized> Arc<T, Owner>

pub fn unsize<U: ?Sized, F>( this: Self, with: Coercion<T, U, F>, ) -> Arc<U, Owner>
where T: Sized, F: FnOnce(*const T) -> *const U,

Available on crate feature unsize only.

Convert this pointer with an unsizing coercion (e.g. from T to dyn Trait or [T; N] to [T]).

pub fn unsize_owner<Pwner: ?Sized, F>( this: Self, with: Coercion<Owner, Pwner, F>, ) -> Arc<T, Pwner>
where Owner: Sized, F: FnOnce(*const Owner) -> *const Pwner,

Available on crate feature unsize only.

Convert this pointer with an unsizing coercion of the owner (e.g. from T to dyn Trait or [T; N] to [T]).