Struct Weak

pub struct Weak<T: ?Sized, Owner: ?Sized = dyn Destruct + Send + Sync> { /* private fields */ }
A projecting version of Weak which allows owning a containing struct but referencing a field.

Implementations

Source

impl<'a, T: 'a + Send + Sync> Weak<T, dyn Destruct + Send + Sync + 'a>

pub fn new() -> Self

Constructs a new Weak<T> with erased owner.

Source

impl<T, Owner> Weak<T, Owner>

pub fn new_owner() -> Self

Constructs a new Weak<T, T> with typed owner.

Source

impl<'a, T: ?Sized, Owner: 'a + Send + Sync> Weak<T, Owner>

pub fn erase_owner(this: Self) -> Weak<T, dyn Destruct + Send + Sync + 'a>

Erases the owning type so that projected Weak<T> can be used uniformly.

Source

impl<T: ?Sized, Owner: ?Sized> Weak<T, Owner>

pub fn as_ptr(&self) -> *const T

Returns a raw pointer to the object T pointed to by this Weak<T>.

The pointer is valid only if there are some strong references. The pointer may be dangling, unaligned, or even null otherwise.

pub fn upgrade(&self) -> Option<Arc<T, Owner>>

Attempts to upgrade the Weak pointer to Arc<T>.

Returns None if no strong references exist.

pub fn owner(this: &Self) -> Weak<Owner>

Gets a reference to the owning allocation.

pub fn into_owner(this: Self) -> Weak<Owner>

Consumes this projected field, returning the owning allocation.

pub fn project<U: Sized>( this: Self, projection: impl FnOnce(&T) -> &U, ) -> Weak<U, Owner>

Projects this allocation to a field.

If no strong references exist, the closure will not be called.

pub fn ptr_eq(lhs: &Self, rhs: &Self) -> bool

Returns true if the two Weaks point to the same field in the same allocated object, or if both don’t point to anything (i.e. because they were created with Weak::new()).

See ptr::eq for the caveats when comparing dyn Trait pointers, which this does when the owner type is erased.

Source

impl<T: ?Sized, Owner: ?Sized> Weak<T, Owner>

pub fn unsize<U: ?Sized, F>( this: Self, with: Coercion<T, U, F>, ) -> Weak<U, Owner>
where T: Sized, F: FnOnce(*const T) -> *const U,

Available on crate feature unsize only.

Convert this pointer with an unsizing coercion (e.g. from T to dyn Trait or [T; N] to [T]).

pub fn unsize_owner<Pwner: ?Sized, F>( this: Self, with: Coercion<Owner, Pwner, F>, ) -> Weak<T, Pwner>
where Owner: Sized, F: FnOnce(*const Owner) -> *const Pwner,

Available on crate feature unsize only.

Convert this pointer with an unsizing coercion of the owner (e.g. from T to dyn Trait or [T; N] to [T]).