Thread-safe reference-counting pointers.

See the Arc documentation for more details.

Structs

A projecting version of Arc which allows owning a containing struct but referencing a field.
A projecting version of Weak which allows owning a containing struct but referencing a field.