pub struct Arc<T: ?Sized, Owner: ?Sized = dyn Destruct + Send + Sync> { /* private fields */ }Expand description
A projecting version of
Arc
which allows owning a containing struct but referencing a field.
Implementations
Sourceimpl<T: ?Sized, Owner: ?Sized> Arc<T, Owner>
impl<T: ?Sized, Owner: ?Sized> Arc<T, Owner>
Sourcepub fn downgrade(this: &Self) -> Weak<T, Owner>
pub fn downgrade(this: &Self) -> Weak<T, Owner>
Creates a new Weak pointer to this projected field.
Sourcepub fn owner(this: &Self) -> Arc<Owner>
pub fn owner(this: &Self) -> Arc<Owner>
Gets a reference to the owning allocation.
This returns a clone of the owning
Arc,
so it cannot return a unique reference. If you want to take
unique ownership, use into_owner instead.
Sourcepub fn into_owner(this: Self) -> Arc<Owner>
pub fn into_owner(this: Self) -> Arc<Owner>
Consumes this projected field and returns the owning allocation.
Sourceimpl<T: ?Sized, Owner: ?Sized> Arc<T, Owner>
impl<T: ?Sized, Owner: ?Sized> Arc<T, Owner>
Sourcepub fn unsize<U: ?Sized, F>(
this: Self,
with: Coercion<T, U, F>,
) -> Arc<U, Owner>
Available on crate feature unsize only.
pub fn unsize<U: ?Sized, F>( this: Self, with: Coercion<T, U, F>, ) -> Arc<U, Owner>
unsize only.Convert this pointer with an unsizing coercion
(e.g. from T to dyn Trait or [T; N] to [T]).
Sourcepub fn unsize_owner<Pwner: ?Sized, F>(
this: Self,
with: Coercion<Owner, Pwner, F>,
) -> Arc<T, Pwner>
Available on crate feature unsize only.
pub fn unsize_owner<Pwner: ?Sized, F>( this: Self, with: Coercion<Owner, Pwner, F>, ) -> Arc<T, Pwner>
unsize only.Convert this pointer with an unsizing coercion of the owner
(e.g. from T to dyn Trait or [T; N] to [T]).