A projecting version of
Arc
which allows owning a containing struct but referencing a field.
Implementations
sourceimpl<'a, T: ?Sized, Owner: 'a + Sized> Arc<T, Owner>
impl<'a, T: ?Sized, Owner: 'a + Sized> Arc<T, Owner>
sourcepub fn erase_owner(this: Self) -> Arc<T, dyn Destruct + 'a>
pub fn erase_owner(this: Self) -> Arc<T, dyn Destruct + 'a>
Erases the owning type so projected Arc can be used uniformly.
sourceimpl<T: ?Sized, Owner: ?Sized> Arc<T, Owner>
impl<T: ?Sized, Owner: ?Sized> Arc<T, Owner>
sourcepub fn downgrade(this: &Self) -> Weak<T, Owner>
pub fn downgrade(this: &Self) -> Weak<T, Owner>
Creates a new Weak pointer to this projected field.
sourcepub fn owner(this: &Self) -> Arc<Owner>
pub fn owner(this: &Self) -> Arc<Owner>
Gets a reference to the owning allocation.
This returns a clone of the owning
Arc,
so it cannot return a unique reference. If you want to take
unique ownership, use into_owner instead.
sourcepub fn into_owner(this: Self) -> Arc<Owner>
pub fn into_owner(this: Self) -> Arc<Owner>
Consumes this projected field and returns the owning allocation.
sourceimpl<T: ?Sized, Owner: ?Sized> Arc<T, Owner>
impl<T: ?Sized, Owner: ?Sized> Arc<T, Owner>
sourcepub fn unsize<U: ?Sized, F>(this: Self, with: Coercion<T, U, F>) -> Arc<U, Owner>where
T: Sized,
F: FnOnce(*const T) -> *const U,
Available on crate feature unsize only.
pub fn unsize<U: ?Sized, F>(this: Self, with: Coercion<T, U, F>) -> Arc<U, Owner>where
T: Sized,
F: FnOnce(*const T) -> *const U,
unsize only.Convert this pointer with an unsizing coercion
(e.g. from T to dyn Trait or [T; N] to [T]).
sourcepub fn unsize_owner<Pwner: ?Sized, F>(
this: Self,
with: Coercion<Owner, Pwner, F>
) -> Arc<T, Pwner>where
Owner: Sized,
F: FnOnce(*const Owner) -> *const Pwner,
Available on crate feature unsize only.
pub fn unsize_owner<Pwner: ?Sized, F>(
this: Self,
with: Coercion<Owner, Pwner, F>
) -> Arc<T, Pwner>where
Owner: Sized,
F: FnOnce(*const Owner) -> *const Pwner,
unsize only.Convert this pointer with an unsizing coercion of the owner
(e.g. from T to dyn Trait or [T; N] to [T]).