pub struct Weak<T: ?Sized, Owner: ?Sized = dyn Destruct> { /* private fields */ }
A projecting version of Weak which allows owning a containing struct but referencing a field.

Implementations

Constructs a new Weak<T>

Returns a raw pointer to the object T pointed to by this Weak<T>.

The pointer is valid only if there are some strong references. The pointer may be dangling, unaligned, or even null otherwise.

Attempts to upgrade the Weak pointer to Arc<T>.

Returns None if no strong references exist.

Gets a reference to the owning allocation.

Consumes this projected field, returning the owning allocation.

Projects this allocation to a field.

If no strong references exist, the closure will not be called.

Returns true if the two Weaks point to the same allocation (similar to ptr::eq), or if both don’t point to any allocation (because they were crated with Weak::new()).

Available on crate feature unsize only.

Convert this pointer with an unsizing coercion (e.g. from T to dyn Trait or [T; N] to [T]).

Available on crate feature unsize only.

Convert this pointer with an unsizing coercion of the owner (e.g. from T to dyn Trait or [T; N] to [T]).