A projecting version of
Weak
which allows owning a containing struct but referencing a field.
Implementations
sourceimpl<'a, T: ?Sized, Owner: 'a + Sized> Weak<T, Owner>
impl<'a, T: ?Sized, Owner: 'a + Sized> Weak<T, Owner>
pub fn erase_owner(this: Self) -> Weak<T, dyn Destruct + 'a>
sourceimpl<T: ?Sized, Owner: ?Sized> Weak<T, Owner>
impl<T: ?Sized, Owner: ?Sized> Weak<T, Owner>
sourcepub fn as_ptr(&self) -> *const T
pub fn as_ptr(&self) -> *const T
Returns a raw pointer to the object T pointed to by this
Weak<T>.
The pointer is valid only if there are some strong references. The pointer may be dangling, unaligned, or even null otherwise.
sourcepub fn upgrade(&self) -> Option<Arc<T, Owner>>
pub fn upgrade(&self) -> Option<Arc<T, Owner>>
Attempts to upgrade the Weak pointer to
Arc<T>.
Returns None if no strong references exist.
sourcepub fn into_owner(this: Self) -> Weak<Owner>
pub fn into_owner(this: Self) -> Weak<Owner>
Consumes this projected field, returning the owning allocation.
sourceimpl<T: ?Sized, Owner: ?Sized> Weak<T, Owner>
impl<T: ?Sized, Owner: ?Sized> Weak<T, Owner>
sourcepub fn unsize<U: ?Sized, F>(
this: Self,
with: Coercion<T, U, F>
) -> Weak<U, Owner>where
T: Sized,
F: FnOnce(*const T) -> *const U,
Available on crate feature unsize only.
pub fn unsize<U: ?Sized, F>(
this: Self,
with: Coercion<T, U, F>
) -> Weak<U, Owner>where
T: Sized,
F: FnOnce(*const T) -> *const U,
unsize only.Convert this pointer with an unsizing coercion
(e.g. from T to dyn Trait or [T; N] to [T]).
sourcepub fn unsize_owner<Pwner: ?Sized, F>(
this: Self,
with: Coercion<Owner, Pwner, F>
) -> Weak<T, Pwner>where
Owner: Sized,
F: FnOnce(*const Owner) -> *const Pwner,
Available on crate feature unsize only.
pub fn unsize_owner<Pwner: ?Sized, F>(
this: Self,
with: Coercion<Owner, Pwner, F>
) -> Weak<T, Pwner>where
Owner: Sized,
F: FnOnce(*const Owner) -> *const Pwner,
unsize only.Convert this pointer with an unsizing coercion of the owner
(e.g. from T to dyn Trait or [T; N] to [T]).