pub trait Destruct { }Expand description
A marker trait for types that can be dropped (all types).
Used as dyn Destruct to represent truly any type. Any
introduces an undesired 'static bound, Drop bounds test uselessly for
explicit Drop implementations, and Sized is not dyn safe, thus this
trait.
See also the unstable std::marker::Destruct.